Resources Module
================
.. automodule:: resources.resources
..   :members: Resources

.. autoclass:: Resources
  :member-order: bysource
  :members:

  .. automethod:: __init__

.. autoclass:: GlobalResources
  :member-order: bysource
  :members:

  .. automethod:: __init__
